==========
Interfaces
==========

.. _povm_toolbox-quantum_info-base:

.. automodule:: povm_toolbox.quantum_info.base
   :members:
   :no-inherited-members:
   :no-special-members:

.. autoclass:: LabelT
   :members:
